#version 330

/**
 * This first defined out variable of the fragment shader defines
 * with which color the fragment is rendered
 */
out vec4 fragment_color;

/**
 * The value of this variable comes from the vertex shader (see
 * 'out vec4 normal_from_vs;' there). Note that input variables
 * in the fragment shader, which comes from the vertex shader,
 * are automatically interpolated.
 */
in vec4 normal_from_vs;

/**
 * This is the color you can define in the IMGUI menu.
 *
 * (In this shader, we don't use the vertex_color attributes or
 * a texture, we just define a single color for the whole mesh
 * in the C++ code)
 */
uniform vec4 colorOfTeapot;

/**
 * Using toon shading (with 5 brightness levels), where the
 * light shines along the z-axis (from screen perspective).
 */
vec4 toonShading(){
    // Vector, in which direction the light should shine:
    vec4 lightDir = vec4(0.0, 0.0, -1.0, 0.0);

    // Dotproduct of light direction and the surface normal:
    float nDotL = dot(normalize(normal_from_vs), lightDir);

    // When we scale nDotL by 5, round the value, and divide
    // it by 5, we get a factor which can be 0.0, 0.2, 0.4
    // 0.6, 0.8 or 1.0. This is multiplicated by the color:
    return colorOfTeapot * round(nDotL * 5.0) / 5.0;
}

/**
 * The main function of the fragment shader, which is executed
 * for every fragment.
 */
void main()
{
    // Set the output color variable to the color of the vertex:
    fragment_color = toonShading();
}
