#version 330

/** Input variable (the position, which is vertex attribute 0) */
layout(location = 0) in vec4 vertex_position;

/** Input variable (the normal, which is vertex attribute 1) */
layout(location = 1) in vec4 vertex_normal;

/** Input variable (the color, which is vertex attribute 2) (NOT USED HERE) */
layout(location = 2) in vec4 vertex_color;

/** Input variable (the tex coord, which is vertex attribute 3) (NOT USED HERE) */
layout(location = 3) in vec4 vertex_texCoord;

/** Output variable which can be used by the fragment shader */
out vec4 normal_from_vs;

/**
 * Transformation matrix of the object (e.g. rotation)
 *
 * Note: Up to exercise 3, this matrix IS the rotationMatrix
 * defined in C++. In exercise 4, this matrix should contain
 * both the translation and the rotation.
 */
uniform mat4 model;

/**
 * Projection matrix (see exercise 5).
 *
 * Note: As long as you don't work on exercise 5, this is an
 * identity matrix (so multiplication don't affect the result).
 */
uniform mat4 projection;


/**
 * Since this is the vertex shader, the following program is
 * executed for each vertex (i.e. triangle point) individually.
 */
void main()
{
    // Rotate also the normal and send it to the fragment shader:
    normal_from_vs = model * vertex_normal;

    // Note that up to exercise 4, the projection matrix is the
    // identity (so it has no affect when it is multiplicated).
    // Also note that the most left matrix is the matrix those
    // transformation is performed at the end / the last:
    gl_Position = projection * model * vertex_position;
}
